.. _linux_mc_repo:

********************
firewheel_repo_linux
********************

This repository contains FIREWHEEL Model Components related to Linux and Linux specific applications.
Currently, there are generic Linux-related MCs as well as MCs related to several Ubuntu distributions.

Building Images
===============

Due to licensing limitations, we are currently unable to provide the expected binary files (VM Resources nor Images) that are used within these model components.
For the VM Resources, we have provided an `INSTALL <https://sandialabs.github.io/firewheel/tutorials/install_file.html>`__ script to reproducibly recreate them, when possible.
However, for images, users will need to follow the `Image Creation Tutorial <https://sandialabs.github.io/firewheel/tutorials/image.html>`__ to create compatible images.
The following images are referenced within this repository:

Located in ``linux.ubuntu1404``
-------------------------------
- `Ubuntu 14.04.5 Server <http://old-releases.ubuntu.com/releases/14.04.5/>`_
- `Ubuntu 14.04.5 Desktop <http://old-releases.ubuntu.com/releases/14.04.5/>`_

Located in ``linux.ubuntu1604``
-------------------------------
- `Ubuntu 16.04.4 Server <http://old-releases.ubuntu.com/releases/16.04.4/>`_
- `Ubuntu 16.04.4 Desktop <http://old-releases.ubuntu.com/releases/16.04.4/>`_

Located in ``linux.ubuntu1804``
-------------------------------
* `Ubuntu 18.04.5 Server <http://old-releases.ubuntu.com/releases/18.04.5/>`_
* `Ubuntu 18.04.5 Desktop <http://old-releases.ubuntu.com/releases/18.04.5/>`_

Located in ``linux.ubuntu2204``
-------------------------------
- `Ubuntu 22.04 Server <https://releases.ubuntu.com/jammy/>`_
- `Ubuntu 22.04 Desktop <https://releases.ubuntu.com/jammy/>`_

